==> 0.43.0.tar.gz: lib/state/base_logic.dart <==
import 'package:flutter/material.dart';
import 'package:slick/navigation/route_configuration.dart';
import 'package:slick/security/security.dart';

class BaseLogic extends ChangeNotifier {
  static String mostRecentError;

  bool initialised = false;

  //screen lifecycle
  Future<void> init() async {
    notifyScreen(true);
  }

  Future<bool> deactivate() async {
    var result = await validate();
    if (!result) return false;
    return true;
  }

  //validation
  List<String> _validationErrors;
  Future<bool> validate() async {
    return true;
  }

  void clearValidation() {
    _validationErrors = [];
  }

  void addValidation(String message) {
    _validationErrors.add(message);
  }

  bool get isValid => _validationErrors.isEmpty;

  //loading / screen ready state
  bool _ready = false;
  bool get ready => _ready;

  //request screen redraw and set ready state
  void notifyScreen([bool ready]) {
    ready ??= true;

    if (!ready) setError('');

    _ready = ready;

    if (currentRouteInfo.building) return;
    super.notifyListeners();
  }

  //navigation
  CurrentRouteConfiguration get currentRouteInfo => currentRouteSingleton;

  void navigate(RouteInfo routeInfo, {Object parameter}) {
    parameter ??= '';
    currentRouteInfo.navigate(routeInfo, parameter: parameter.toString());
  }

  //security
  SlickUser get currentUser => SlickSecurity.currentUser;

  bool get hasViewAccess => currentRouteInfo.currentUserHasViewAccess();
  bool get hasEditAccess => true;

  String _error;
  void setError(dynamic error) {
    if (error == null) {
      _error = null;
      mostRecentError = _error;
    } else {
      _error = error.toString();
      mostRecentError = _error;
    }
    notifyListeners();
  }

  //screen error state
  String get error => _error;

  bool get hasError => _error != null;

  //screen success state
  String message = '';
  void setMessage(String text) {
    message = text;
    notifyListeners();
  }
}

==> 0.48.0.tar.gz: lib/state/base_logic.dart <==
import 'package:flutter/material.dart';
import 'package:slick/navigation/route_configuration.dart';
import 'package:slick/security/security.dart';

class BaseLogic extends ChangeNotifier {
  static String mostRecentError;

  bool initialised = false;

  //screen lifecycle
  Future<void> init() async {
    notifyScreen(true);
  }

  Future<bool> deactivate() async {
    var result = await validate();
    if (!result) return false;
    return true;
  }

  //validation
  List<String> _validationErrors;
  Future<bool> validate() async {
    return true;
  }

  void clearValidation() {
    _validationErrors = [];
  }

  void addValidation(String message) {
    _validationErrors.add(message);
  }

  bool get isValid => _validationErrors.isEmpty;

  //loading / screen ready state
  bool _ready = false;
  bool get ready => _ready;

  //request screen redraw and set ready state
  void notifyScreen([bool ready]) {
    ready ??= true;

    if (ready) {
      initialised = true;
      currentRouteInfo.reInit = false;
    }

    if (!ready) setMessage('');
    _ready = ready;

    if (currentRouteInfo.building) return;
    super.notifyListeners();
  }

  //navigation
  CurrentRouteConfiguration get currentRouteInfo => currentRouteSingleton;

  void navigate(RouteInfo routeInfo, {Object parameter}) {
    parameter ??= '';
    currentRouteInfo.navigate(routeInfo, parameter: parameter.toString());
  }

  //security
  SlickUser get currentUser => SlickSecurity.currentUser;

  bool get hasViewAccess => currentRouteInfo.currentUserHasViewAccess();
  bool get hasEditAccess => true;

  String _error;
  void setError(dynamic error) {
    if (error == null) {
      _error = null;
      mostRecentError = _error;
    } else {
      _error = error.toString();
      mostRecentError = _error;
    }
    notifyListeners();
  }

  //screen error state
  String get error => _error;

  bool get hasError => _error != null;

  //screen success state
  String message = '';
  void setMessage(String text) {
    message = text;
    notifyListeners();
  }
}
